@@ -213,7 +213,7 @@ def get_fakebase_header(incomplete, extend, space):
 
 def filter_fakeitem_names(listdir, include_folders=None,
                           exclude_folders=None, include_files=None,
-                          exclude_files=None, regex=False):
+                          exclude_files=None, regex=False, mask=None):
     '''
     Filter for folder and file names in seedir.FakeDir.seedir().  Removes or
     includes items matching filtering strings.
@@ -230,6 +230,10 @@ def filter_fakeitem_names(listdir, include_folders=None,
         File names to include. The default is None.
     exclude_files : str or list-like, optional
         File names to exclude. The default is None.
+    mask : function, optional
+        Function for filtering items.  Each individual item object
+        are passed to the mask function.  If True is returned, the
+        item is kept.  The default is None.
     regex : bool, optional
         Interpret strings as regular expressions. The default is False.
 
@@ -247,6 +251,10 @@ def filter_fakeitem_names(listdir, include_folders=None,
     '''
     keep = []
     for l in listdir:
+        if mask is not None:
+            if mask(l) is not True:
+                continue
+
         if isinstance(l, FakeDir):
             if isinstance(include_folders, str):
                 if not printing.is_match(include_folders, l.name, regex):
@@ -307,7 +315,7 @@ def recursive_fakedir_structure(fakedir, depth=0, incomplete=None, split='├─
                                 sort=True, sort_reverse=False, sort_key=None,
                                 include_folders=None, exclude_folders=None,
                                 include_files=None, exclude_files=None,
-                                regex=False, slash='/'):
+                                regex=False, mask=None, slash='/'):
     '''
     Recursive function for generating folder structures.  Main tool for
     building output generated by seedir.FakeDir.seedir()
@@ -358,6 +366,10 @@ def recursive_fakedir_structure(fakedir, depth=0, incomplete=None, split='├─
     regex : bool, optional
         Interpret include/exclude file/folder arguments as
         regular expressions. The default is False.
+    mask : function, optional
+        Function for filtering items.  Each individual item object
+        are passed to the mask function.  If True is returned, the
+        item is kept.  The default is None.
     slash : str, option:
         Slash character to follow folders.  If 'sep', uses os.sep.  The
         default is '/'.
@@ -404,13 +416,14 @@ def recursive_fakedir_structure(fakedir, depth=0, incomplete=None, split='├─
             include_folders,
             exclude_folders,
             include_files,
-            exclude_files]):
+            exclude_files,
+            mask]):
         listdir = filter_fakeitem_names(listdir,
                                         include_folders=include_folders,
                                         exclude_folders=exclude_folders,
                                         include_files=include_files,
                                         exclude_files=exclude_files,
-                                        regex=regex)
+                                        regex=regex, mask=mask)
     if not listdir:
         if depth - 1 in incomplete:
             incomplete.remove(depth-1) # remove from incomplete if empty
@@ -464,6 +477,7 @@ def recursive_fakedir_structure(fakedir, depth=0, incomplete=None, split='├─
                                                  include_files=include_files,
                                                  exclude_files=exclude_files,
                                                  regex=regex,
+                                                 mask=mask,
                                                  slash=slash)
 
         # only concat to output if file
@@ -568,6 +582,14 @@ class FakeItem:
         else:
             self.depth = self.parent.depth + 1
 
+    def isfile(self):
+        """Returns True if instance is a FakeFile object"""
+        return isinstance(self, FakeFile)
+
+    def isdir(self):
+        """Returns True if instance is a FakeDir object"""
+        return isinstance(self, FakeDir)
+
 class FakeFile(FakeItem):
     '''Class to represent files in FakeDir objects.'''
     def __init__(self, name, parent=None):
@@ -723,7 +745,8 @@ class FakeDir(FakeItem):
                anystart=None, depthlimit=None, itemlimit=None, beyond=None,
                first=None, sort=False, sort_reverse=False, sort_key=None,
                include_folders=None, exclude_folders=None, include_files=None,
-               exclude_files=None, regex=False, slash='/', **kwargs):
+               exclude_files=None, regex=False, slash='/', mask=None,
+               **kwargs):
         '''
 
         Create a folder tree diagram for self.  FakeDir version of
@@ -790,6 +813,13 @@ class FakeDir(FakeItem):
         regex : bool, optional
             Interpret the strings of include/exclude file/folder arguments as
             regular expressions. The default is False.
+        mask : function, optional
+            Function for filtering items.  Each individual item object
+            are passed to the mask function.  If True is returned, the
+            item is kept.  The default is None.
+        slash : str, option:
+            Slash character to follow folders.  If 'sep', uses os.sep.  The
+            default is '/'.
         **kwargs : str
             Specific tokens to use for creating the file tree diagram.  The tokens
             use by each builtin style can be seen with sd.get_styleargs().  Valid
@@ -855,6 +885,7 @@ class FakeDir(FakeItem):
                                            exclude_files=exclude_files,
                                            regex=regex,
                                            slash=slash,
+                                           mask=mask,
                                            **styleargs).strip()
         if printout:
             print(rfs)
@@ -1035,7 +1066,7 @@ def recursive_add_fakes(path, parent, depth=0, depthlimit=None,
                         sort_reverse=False, sort_key=None,
                         include_folders=None, exclude_folders=None,
                         include_files=None, exclude_files=None,
-                        regex=False):
+                        mask=None, regex=False):
     '''
     Recursive helper function for seedir.fakedir(), for creating a
     fake folder tree from a real one.
@@ -1063,6 +1094,10 @@ def recursive_add_fakes(path, parent, depth=0, depthlimit=None,
         Key function for sorting item names. The default is None.
     include_folders, exclude_folders, include_files, exclude_files : str, list-like, or None, optional
             Folder / file names to include or exclude. The default is None.
+    mask : function, optional
+        Function for filtering items.  Absolute paths of each individual item
+        are passed to the mask function.  If True is returned, the
+        item is kept.  The default is None.
     regex : bool, optional
         Interpret include/exclude folder/file arguments as regular
         expressions. The default is False.
@@ -1083,13 +1118,15 @@ def recursive_add_fakes(path, parent, depth=0, depthlimit=None,
             include_folders,
             exclude_folders,
             include_files,
-            exclude_files]):
+            exclude_files,
+            mask]):
         listdir = filter_item_names(path, listdir,
                                     include_folders=include_folders,
                                     exclude_folders=exclude_folders,
                                     include_files=include_files,
                                     exclude_files=exclude_files,
-                                    regex=regex)
+                                    regex=regex,
+                                    mask=mask)
     for i, f in enumerate(listdir):
         if i == itemlimit:
             break
@@ -1102,14 +1139,15 @@ def recursive_add_fakes(path, parent, depth=0, depthlimit=None,
                                 include_folders=include_folders,
                                 exclude_folders=exclude_folders,
                                 include_files=include_files,
-                                exclude_files=exclude_files, regex=regex)
+                                exclude_files=exclude_files,
+                                mask=mask, regex=regex)
         else:
             new = FakeFile(f, parent=parent)
 
 def fakedir(path, depthlimit=None, itemlimit=None, first=None,
             sort=False, sort_reverse=False, sort_key=None,
             include_folders=None, exclude_folders=None, include_files=None,
-            exclude_files=None, regex=True):
+            exclude_files=None, mask=None, regex=True):
     '''
     Function for creating a seedir.FakeDir (representation of a directory)
     from a real system directory.  Rather than immediately representing
@@ -1140,6 +1178,10 @@ def fakedir(path, depthlimit=None, itemlimit=None, first=None,
         Key function for sorting the file names. The default is None.
     include_folders, exclude_folders, include_files, exclude_files : str, list-like, or None, optional
             Folder / file names to include or exclude. The default is None.
+    mask : function, optional
+        Function for filtering items.  Absolute paths of each individual item
+        are passed to the mask function.  If True is returned, the
+        item is kept.  The default is None.
     regex : bool, optional
         Interpret include/exclude folder/file arguments as regular
         expressions. The default is False.
@@ -1167,7 +1209,8 @@ def fakedir(path, depthlimit=None, itemlimit=None, first=None,
                         include_folders=include_folders,
                         exclude_folders=exclude_folders,
                         include_files=include_files,
-                        exclude_files=exclude_files, regex=regex)
+                        exclude_files=exclude_files,
+                        mask=mask, regex=regex)
     return output
 
 def fakedir_fromstring(s, start_chars=None, name_chars=None,
