@@ -213,7 +213,8 @@ def get_base_header(incomplete, extend, space):
 
 def filter_item_names(root, listdir, include_folders=None,
                       exclude_folders=None, include_files=None,
-                      exclude_files=None, regex=False):
+                      exclude_files=None, regex=False,
+                      mask=None):
     '''
     Filter for folder and file names in seedir.seedir().  Removes or includes
     items matching filtering strings.
@@ -235,6 +236,10 @@ def filter_item_names(root, listdir, include_folders=None,
         File names to exclude. The default is None.
     regex : bool, optional
         Interpret strings as regular expressions. The default is False.
+    mask : function, optional
+        Function for filtering items.  Absolute paths of each individual item
+        are passed to the mask function.  If True is returned, the
+        item is kept.  The default is None.
 
     Raises
     ------
@@ -252,6 +257,10 @@ def filter_item_names(root, listdir, include_folders=None,
     for l in listdir:
         sub = os.path.join(root, l)
 
+        if mask is not None:
+            if mask(sub) is not True:
+                continue
+
         if os.path.isdir(sub):
             if isinstance(include_folders, str):
                 if not printing.is_match(include_folders, l, regex):
@@ -313,7 +322,7 @@ def recursive_folder_structure(path, depth=0, incomplete=None, extend='│ ',
                                sort=True, sort_reverse=False, sort_key=None,
                                include_folders=None, exclude_folders=None,
                                include_files=None, exclude_files=None,
-                               regex=False, slash='/'):
+                               regex=False, mask=None, slash='/'):
     '''
     Recursive function for generating folder structures.  Main tool for
     building output generated by seedir.seedir().
@@ -364,6 +373,10 @@ def recursive_folder_structure(path, depth=0, incomplete=None, extend='│ ',
     regex : bool, optional
         Interpret include/exclude file/folder arguments as
         regular expressions. The default is False.
+    mask : function, optional
+        Function for filtering items.  Absolute paths of each individual item
+        are passed to the mask function.  If True is returned, the
+        item is kept.  The default is None.
     slash : str, option:
         Slash character to follow folders.  If 'sep', uses os.sep.  The
         default is '/'.
@@ -410,13 +423,15 @@ def recursive_folder_structure(path, depth=0, incomplete=None, extend='│ ',
             include_folders,
             exclude_folders,
             include_files,
-            exclude_files]):
+            exclude_files,
+            mask]):
         listdir = filter_item_names(path, listdir,
                                     include_folders=include_folders,
                                     exclude_folders=exclude_folders,
                                     include_files=include_files,
                                     exclude_files=exclude_files,
-                                    regex=regex)
+                                    regex=regex,
+                                    mask=mask)
     if not listdir:
         if depth - 1 in incomplete:
             incomplete.remove(depth-1) # remove from incomplete if empty
@@ -472,6 +487,7 @@ def recursive_folder_structure(path, depth=0, incomplete=None, extend='│ ',
                                                  include_files=include_files,
                                                  exclude_files=exclude_files,
                                                  regex=regex,
+                                                 mask=mask,
                                                  slash=slash)
 
         # only concat to output if file
@@ -483,7 +499,7 @@ def seedir(path=None, style='lines', printout=True, indent=2, uniform=None,
            anystart=None, depthlimit=None, itemlimit=None, beyond=None,
            first=None, sort=False, sort_reverse=False, sort_key=None,
            include_folders=None, exclude_folders=None, include_files=None,
-           exclude_files=None, regex=False, slash='/', **kwargs):
+           exclude_files=None, regex=False, mask=None, slash='/', **kwargs):
     '''
 
     Primary function of the seedir package: generate folder trees for
@@ -629,6 +645,13 @@ def seedir(path=None, style='lines', printout=True, indent=2, uniform=None,
     regex : bool, optional
         Interpret the strings of include/exclude file/folder arguments as
         regular expressions. The default is False.
+    mask : function, optional
+        Function for filtering items.  Absolute paths of each individual item
+        are passed to the mask function.  If True is returned, the
+        item is kept.  The default is None.
+    slash : str, option:
+        Slash character to follow folders.  If 'sep', uses os.sep.  The
+        default is '/'.
     **kwargs : str
         Specific tokens to use for creating the file tree diagram.  The tokens
         use by each builtin style can be seen with sd.get_styleargs().  Valid
@@ -696,6 +719,7 @@ def seedir(path=None, style='lines', printout=True, indent=2, uniform=None,
                                       exclude_files=exclude_files,
                                       regex=regex,
                                       slash=slash,
+                                      mask=mask,
                                       **styleargs).strip()
     if printout:
         print(rfs)
